__version__ = '0.3.2'
__title__ = 'koinput'
__author__ = 'k0per'
__copyright__ = 'Copyright 2021-present k0per'

from colorama import init

init()

from koinput.menu import Menu
from koinput.inputs import int_input, float_input
from koinput.progress_bar import ProgressBar

__all__ = [
    'int_input',
    'float_input',
    'Menu',
    'ProgressBar'
]



from colorama import Fore
import sys
from koinput.inputs import int_input


class Menu:

    def __init__(self):
        self.__items = {}

    def add_to_menu(self, name: str, func, *args):
        self.__items[name] = (func, args)

    def add_to_menu_dec(self, name: str, *args):
        def decorator(func):
            self.__items[name] = (func, args)
            return func

        return decorator

    @staticmethod
    def menu_exit(exit_offer: str):
        def f():
            print(exit_offer, end='')
            input()

        return f

    def reassign_menu_exit(self):
        def decorator(func):
            self.menu_exit = func
            return func

        return decorator

    def show_menu(self, title: str = None, title_style: str = None, number_of_leading_spaces_title: int = 2,
                  console_style: str = Fore.RESET, order_of_items: tuple = None, number_of_leading_spaces: int = 4,
                  separator: str = ' - ', items_style: str = None, input_suggestion: str = 'Select a menu item: ',
                  enable_menu_item_exit: bool = True, menu_item_exit: str = 'Exit',
                  exit_offer: str = 'Press Enter to exit...', input_suggestion_style: str = None):

        # Type check
        if type(title) != str and title is not None:
            raise TypeError('title must be str')
        if type(title_style) != str and title_style is not None:
            raise TypeError('title_colour must be str')
        if type(items_style) != str and items_style is not None:
            raise TypeError('items_style must be str')
        if type(input_suggestion_style) != str and input_suggestion_style is not None:
            raise TypeError('input_suggestion_style must be str')
        if type(number_of_leading_spaces) != int:
            raise TypeError('number_of_leading_spaces must be int')
        if type(number_of_leading_spaces_title) != int:
            raise TypeError('number_of_leading_spaces_title must be int')
        if type(console_style) != str:
            raise TypeError('console_colour must be str')
        if type(separator) != str:
            raise TypeError('separator must be str')
        if type(input_suggestion) != str:
            raise TypeError('input_suggestion must be str')
        if type(enable_menu_item_exit) != bool:
            raise TypeError('enable_menu_item_exit must be bool')
        if type(menu_item_exit) != str:
            raise TypeError('menu_item_exit must be str')
        if type(exit_offer) != str:
            raise TypeError('exit_offer must be str')
        if type(order_of_items) != tuple and order_of_items is not None:
            raise TypeError('order_of_items must be a tuple of int or str')

        # order_of_items type check
        order_of_items_is_int_tuple = True
        if order_of_items is not None:
            for item in order_of_items:
                if type(item) != int:
                    order_of_items_is_int_tuple = False
                    for itemstr in order_of_items:
                        if type(itemstr) != str:
                            raise TypeError('order_of_items must be a tuple of int or str')
                        if itemstr not in self.__items:
                            raise IndexError(
                                'order_of_items consisting of str must contain only the names of menu items')
                    break
                if item < 0 or item >= len(self.__items):
                    raise IndexError(
                        'order_of_items consisting of int must contain only '
                        'ordinal numbers of menu items starting from 0')

        if enable_menu_item_exit:
            self.add_to_menu(menu_item_exit, self.menu_exit(exit_offer))

        while True:
            # Title
            if title is not None:
                if title_style is not None:
                    sys.stdout.write(title_style + '\r')
                    sys.stdout.write(' ' * len(title_style) + '\r')
                sys.stdout.write(' ' * number_of_leading_spaces_title + title + console_style + '\n')

            # Menu
            number = 1
            if order_of_items is None:
                for name in list(self.__items.keys()):
                    if items_style is not None:
                        sys.stdout.write(items_style + '\r')
                        sys.stdout.write(' ' * len(items_style) + '\r')
                    sys.stdout.write(' ' * number_of_leading_spaces + f'{number}{separator}{name}{console_style}\n')
                    number += 1
                x = int_input(input_suggestion=input_suggestion, greater=0, less=number,
                              input_suggestion_style=input_suggestion_style)
                if x == number - 1:
                    enable_menu_item_exit = False
                item = self.__items[list(self.__items.keys())[x - 1]]
                if item[0] is not None:
                    item[0](*item[1])

            elif order_of_items_is_int_tuple:
                if enable_menu_item_exit:
                    order_of_items = (*order_of_items, len(self.__items.keys()) - 1)
                for i in order_of_items:
                    if items_style is not None:
                        sys.stdout.write(items_style + '\r')
                        sys.stdout.write(' ' * len(items_style) + '\r')
                    sys.stdout.write(
                        ' ' * number_of_leading_spaces + f'{number}{separator}{list(self.__items.keys())[i]}{console_style}\n')
                    number += 1
                x = int_input(input_suggestion=input_suggestion, greater=0, less=number,
                              input_suggestion_style=input_suggestion_style)
                if x == number - 1:
                    enable_menu_item_exit = False
                item = self.__items[list(self.__items.keys())[order_of_items[x - 1]]]
                if item[0] is not None:
                    item[0](*item[1])

            else:
                if enable_menu_item_exit:
                    order_of_items = (*order_of_items, menu_item_exit)
                for i in order_of_items:
                    if items_style is not None:
                        sys.stdout.write(items_style + '\r')
                        sys.stdout.write(' ' * len(items_style) + '\r')
                    sys.stdout.write(' ' * number_of_leading_spaces + f'{number}{separator}{i}{console_style}\n')
                    number += 1
                x = int_input(input_suggestion=input_suggestion, greater=0, less=number,
                              input_suggestion_style=input_suggestion_style)
                if x == number - 1:
                    enable_menu_item_exit = False
                item = self.__items[order_of_items[x - 1]]
                if item[0] is not None:
                    item[0](*item[1])

            if not enable_menu_item_exit:
                break



import sys
from colorama import Fore


def int_input(input_suggestion: str = '', greater: float or int = float('-inf'), less: float or int = float('inf'),
              console_style: str = Fore.RESET, error_message: str = 'Invalid number format.\n',
              error_message_style: str = Fore.RED, multiple_numbers_in_line: bool = False,
              input_is_greater_than_less_error: str = "The number is greater than acceptable.\n",
              input_is_less_than_greater_error: str = "The number is less than acceptable.\n",
              input_is_less_error_style: str = None, input_is_greater_error_style: str = None,
              strictly_greater: bool = True, strictly_less: bool = True,
              input_suggestion_style: str = None) -> int or list:
    # type check
    if type(input_suggestion) != str:
        raise TypeError('input_suggestion must be str')
    if type(greater) != int and type(greater) != float:
        raise TypeError('greater must be int or float')
    if type(less) != int and type(less) != float:
        raise TypeError('greater must be int or float')
    if type(error_message) != str:
        raise TypeError('error_message must be str')
    if type(console_style) != str:
        raise TypeError('console_colour must be str')
    if type(error_message_style) != str:
        raise TypeError('error_message_colour must be str')
    if type(input_is_greater_than_less_error) != str:
        raise TypeError('input_is_greater_than_less_error must be str')
    if type(input_is_less_than_greater_error) != str:
        raise TypeError('input_is_less_than_greater_error must be str')
    if type(input_is_less_error_style) != str and input_is_less_error_style is not None:
        raise TypeError('input_is_greater_error_style must be str')
    if type(input_is_greater_error_style) != str and input_is_greater_error_style is not None:
        raise TypeError('input_is_greater_error_style must be str')
    if type(input_suggestion_style) != str and input_suggestion_style is not None:
        raise TypeError('input_suggestion_style must be str')
    if type(strictly_greater) != bool:
        raise TypeError('strictly_greater must be bool')
    if type(strictly_less) != bool:
        raise TypeError('strictly_less must be bool')
    if type(multiple_numbers_in_line) != bool:
        raise TypeError('multiple_numbers_in_line must be bool')

    # error colour
    if input_is_less_error_style is None:
        input_is_less_error_style = error_message_style
    if input_is_greater_error_style is None:
        input_is_greater_error_style = error_message_style

    # input
    while True:
        try:
            if input_suggestion_style is not None:
                sys.stdout.write(input_suggestion_style + '\r')
                sys.stdout.write(' ' * len(input_suggestion_style) + '\r')
                sys.stdout.write(input_suggestion + console_style)
            else:
                sys.stdout.write(input_suggestion)
            if not multiple_numbers_in_line:
                introduced = int(input().split()[0])
                if introduced <= greater and strictly_greater:
                    sys.stdout.write(input_is_greater_error_style + '\r')
                    sys.stdout.write(' ' * len(input_is_greater_error_style) + '\r')
                    sys.stdout.write(input_is_less_than_greater_error + console_style)
                elif introduced < greater and not strictly_greater:
                    sys.stdout.write(input_is_greater_error_style + '\r')
                    sys.stdout.write(' ' * len(input_is_greater_error_style) + '\r')
                    sys.stdout.write(input_is_less_than_greater_error + console_style)
                elif introduced >= less and strictly_less:
                    sys.stdout.write(input_is_less_error_style + '\r')
                    sys.stdout.write(' ' * len(input_is_less_error_style) + '\r')
                    sys.stdout.write(input_is_greater_than_less_error + console_style)
                elif introduced > less and not strictly_less:
                    sys.stdout.write(input_is_less_error_style + '\r')
                    sys.stdout.write(' ' * len(input_is_less_error_style) + '\r')
                    sys.stdout.write(input_is_greater_than_less_error + console_style)
                else:
                    return introduced
            else:
                introduced_list = list(map(int, input().split()))
                for introduced in introduced_list:
                    if introduced <= greater and strictly_greater:
                        sys.stdout.write(input_is_greater_error_style + '\r')
                        sys.stdout.write(' ' * len(input_is_greater_error_style) + '\r')
                        sys.stdout.write(input_is_less_than_greater_error + console_style)
                        break
                    elif introduced < greater and not strictly_greater:
                        sys.stdout.write(input_is_greater_error_style + '\r')
                        sys.stdout.write(' ' * len(input_is_greater_error_style) + '\r')
                        sys.stdout.write(input_is_less_than_greater_error + console_style)
                        break
                    elif introduced >= less and strictly_less:
                        sys.stdout.write(input_is_less_error_style + '\r')
                        sys.stdout.write(' ' * len(input_is_less_error_style) + '\r')
                        sys.stdout.write(input_is_greater_than_less_error + console_style)
                        break
                    elif introduced > less and not strictly_less:
                        sys.stdout.write(input_is_less_error_style + '\r')
                        sys.stdout.write(' ' * len(input_is_less_error_style) + '\r')
                        sys.stdout.write(input_is_greater_than_less_error + console_style)
                        break
                return introduced_list
        except Exception:
            sys.stdout.write(error_message_style + '\r')
            sys.stdout.write(' ' * len(error_message_style) + '\r')
            sys.stdout.write(error_message + console_style)


def float_input(input_suggestion: str = '', greater: float or int = float('-inf'), less: float or int = float('inf'),
                console_style: str = Fore.RESET, error_message: str = 'Invalid number format.\n',
                error_message_style: str = Fore.RED, multiple_numbers_in_line: bool = False,
                input_is_greater_than_less_error: str = "The number is greater than acceptable.\n",
                input_is_less_than_greater_error: str = "The number is less than acceptable.\n",
                input_is_less_error_style: str = None, input_is_greater_error_style: str = None,
                strictly_greater: bool = True, strictly_less: bool = True,
                input_suggestion_style: str = None) -> float or list:
    # type check
    if type(input_suggestion) != str:
        raise TypeError('input_suggestion must be str')
    if type(greater) != int and type(greater) != float:
        raise TypeError('greater must be int or float')
    if type(less) != int and type(less) != float:
        raise TypeError('greater must be int or float')
    if type(error_message) != str:
        raise TypeError('error_message must be str')
    if type(console_style) != str:
        raise TypeError('console_colour must be str')
    if type(error_message_style) != str:
        raise TypeError('error_message_colour must be str')
    if type(input_is_greater_than_less_error) != str:
        raise TypeError('input_is_greater_than_less_error must be str')
    if type(input_is_less_than_greater_error) != str:
        raise TypeError('input_is_less_than_greater_error must be str')
    if type(input_is_less_error_style) != str and input_is_less_error_style is not None:
        raise TypeError('input_is_greater_error_style must be str')
    if type(input_is_greater_error_style) != str and input_is_greater_error_style is not None:
        raise TypeError('input_is_greater_error_style must be str')
    if type(input_suggestion_style) != str and input_suggestion_style is not None:
        raise TypeError('input_suggestion_style must be str')
    if type(strictly_greater) != bool:
        raise TypeError('strictly_greater must be bool')
    if type(strictly_less) != bool:
        raise TypeError('strictly_less must be bool')
    if type(multiple_numbers_in_line) != bool:
        raise TypeError('multiple_numbers_in_line must be bool')

    # error colour
    if input_is_less_error_style is None:
        input_is_less_error_style = error_message_style
    if input_is_greater_error_style is None:
        input_is_greater_error_style = error_message_style

    # input
    while True:
        try:
            if input_suggestion_style is not None:
                sys.stdout.write(input_suggestion_style + '\r')
                sys.stdout.write(' ' * len(input_suggestion_style) + '\r')
                sys.stdout.write(input_suggestion + console_style)
            else:
                sys.stdout.write(input_suggestion)
            if not multiple_numbers_in_line:
                introduced = float(input().split()[0])
                if introduced <= greater and strictly_greater:
                    sys.stdout.write(input_is_greater_error_style + '\r')
                    sys.stdout.write(' ' * len(input_is_greater_error_style) + '\r')
                    sys.stdout.write(input_is_less_than_greater_error + console_style)
                elif introduced < greater and not strictly_greater:
                    sys.stdout.write(input_is_greater_error_style + '\r')
                    sys.stdout.write(' ' * len(input_is_greater_error_style) + '\r')
                    sys.stdout.write(input_is_less_than_greater_error + console_style)
                elif introduced >= less and strictly_less:
                    sys.stdout.write(input_is_less_error_style + '\r')
                    sys.stdout.write(' ' * len(input_is_less_error_style) + '\r')
                    sys.stdout.write(input_is_greater_than_less_error + console_style)
                elif introduced > less and not strictly_less:
                    sys.stdout.write(input_is_less_error_style + '\r')
                    sys.stdout.write(' ' * len(input_is_less_error_style) + '\r')
                    sys.stdout.write(input_is_greater_than_less_error + console_style)
                else:
                    return introduced
            else:
                introduced_list = list(map(float, input().split()))
                for introduced in introduced_list:
                    if introduced <= greater and strictly_greater:
                        sys.stdout.write(input_is_greater_error_style + '\r')
                        sys.stdout.write(' ' * len(input_is_greater_error_style) + '\r')
                        sys.stdout.write(input_is_less_than_greater_error + console_style)
                        break
                    elif introduced < greater and not strictly_greater:
                        sys.stdout.write(input_is_greater_error_style + '\r')
                        sys.stdout.write(' ' * len(input_is_greater_error_style) + '\r')
                        sys.stdout.write(input_is_less_than_greater_error + console_style)
                        break
                    elif introduced >= less and strictly_less:
                        sys.stdout.write(input_is_less_error_style + '\r')
                        sys.stdout.write(' ' * len(input_is_less_error_style) + '\r')
                        sys.stdout.write(input_is_greater_than_less_error + console_style)
                        break
                    elif introduced > less and not strictly_less:
                        sys.stdout.write(input_is_less_error_style + '\r')
                        sys.stdout.write(' ' * len(input_is_less_error_style) + '\r')
                        sys.stdout.write(input_is_greater_than_less_error + console_style)
                        break
                return introduced_list
        except Exception:
            sys.stdout.write(error_message_style + '\r')
            sys.stdout.write(' ' * len(error_message_style) + '\r')
            sys.stdout.write(error_message + console_style)



import sys
import ctypes
import math


# TODO: сделать отдельный стиль для текста и прогресс бара
# TODO: сделать стили сегментов прогресс бара
# TODO: если текст стиль или прогресс бар стиль не ноне консоль стиль не ноне всегда


class ProgressBar:
    max_value: int or float = 100
    counter: bool = False
    string: str = "[########################################] @@@%"
    progressbar_symbol: str = "#"
    percent_symbol: str = "@"
    counter_separator: str = '/'

    __processed_string = None

    @staticmethod
    def show(value: int or float, text: str = None):

        # Проверка значений вводимых данных
        if type(ProgressBar.counter) != bool:
            raise ValueError('ProgressBar.counter must be bool')
        if type(ProgressBar.counter_separator) != str:
            raise ValueError('ProgressBar.counter_separator must be str')

        if ProgressBar.counter:  # если counter true то только int для value и max_value
            if type(value) != int and type(value) != float:
                raise ValueError('If ProgressBar.counter = True, then value must be int.')
            if type(ProgressBar.max_value) != int and type(ProgressBar.max_value) != float:
                raise ValueError('If ProgressBar.counter = True, then ProgressBar.max_value must be int.')
        else:
            if type(value) != int and type(value) != float:
                raise ValueError('value must be int or float')
            if type(ProgressBar.max_value) != int and type(ProgressBar.max_value) != float:
                raise ValueError('ProgressBar.max_value must be int or float')

        if type(ProgressBar.string) != str:
            raise ValueError('ProgressBar.string must be str')
        if type(ProgressBar.progressbar_symbol) != str:
            raise ValueError('ProgressBar.progressbar_symbol must be one element str')
        if type(ProgressBar.percent_symbol) != str:
            raise ValueError('ProgressBar.percent_symbol must be one element str')
        if len(ProgressBar.progressbar_symbol) != 1:
            raise ValueError('ProgressBar.progressbar_symbol must be one element str')
        if len(ProgressBar.percent_symbol) != 1:
            raise ValueError('ProgressBar.percent_symbol must be one element str')

        if value > ProgressBar.max_value:
            raise ValueError('value must be less than ProgressBar.max_value')

        # обработка изменения string
        if ProgressBar.string != ProgressBar.__processed_string:

            # поиск прогресс бара
            symbol_was_found = False
            i = 0
            # TODO: использовать str.find
            while i < len(ProgressBar.string):
                if ProgressBar.string[i] == ProgressBar.progressbar_symbol:
                    symbol_was_found = True
                    ProgressBar.progressbar_start = i
                    try:  # TODO: избавиться от этой херни
                        while ProgressBar.string[i] == ProgressBar.progressbar_symbol:
                            i += 1
                    except IndexError:
                        pass
                    ProgressBar.progressbar_length = i - ProgressBar.progressbar_start
                    break
                i += 1
            if not symbol_was_found:
                raise ValueError('ProgressBar.progressbar_symbol was not found in ProgressBar.string')

            # поиск процентов
            symbol_was_found = False
            i = 0
            while i < len(ProgressBar.string):
                if ProgressBar.string[i] == ProgressBar.percent_symbol:
                    symbol_was_found = True
                    ProgressBar.percent_start = i
                    try:
                        while ProgressBar.string[i] == ProgressBar.percent_symbol:
                            i += 1
                    except IndexError:
                        pass
                    ProgressBar.percent_length = i - ProgressBar.percent_start
                    if ProgressBar.percent_length < 2:
                        ProgressBar.percent_length = 2
                    break
                i += 1
            if not symbol_was_found:
                raise ValueError('ProgressBar.percent_symbol was not found in ProgressBar.string')

            ProgressBar.__processed_string = ProgressBar.string
            # Очистка string
            ProgressBar.cleared_string = ProgressBar.string.replace(ProgressBar.progressbar_symbol, '')
            ProgressBar.cleared_string = ProgressBar.cleared_string.replace(ProgressBar.percent_symbol, '')
            # массив id символ старт
            ProgressBar.symbols_ids = sorted([id(ProgressBar.progressbar_start),
                                              id(ProgressBar.percent_start)],
                                             key=lambda x: ctypes.cast(x, ctypes.py_object).value)

        # изменение выходного string
        string = ProgressBar.cleared_string
        for operation_id in ProgressBar.symbols_ids:

            # ProgressBar.progressbar_start
            if operation_id == id(ProgressBar.progressbar_start):
                progressbar = ''
                percent = value / ProgressBar.max_value
                progressbar += '█' * math.floor(percent * ProgressBar.progressbar_length)
                if percent * ProgressBar.progressbar_length - math.floor(
                        percent * ProgressBar.progressbar_length) > 7 / 8:
                    progressbar += '▉'
                elif percent * ProgressBar.progressbar_length - math.floor(
                        percent * ProgressBar.progressbar_length) > 6 / 8:
                    progressbar += '▊'
                elif percent * ProgressBar.progressbar_length - math.floor(
                        percent * ProgressBar.progressbar_length) > 5 / 8:
                    progressbar += '▋'
                elif percent * ProgressBar.progressbar_length - math.floor(
                        percent * ProgressBar.progressbar_length) > 4 / 8:
                    progressbar += '▌'
                elif percent * ProgressBar.progressbar_length - math.floor(
                        percent * ProgressBar.progressbar_length) > 3 / 8:
                    progressbar += '▍'
                elif percent * ProgressBar.progressbar_length - math.floor(
                        percent * ProgressBar.progressbar_length) > 2 / 8:
                    progressbar += '▎'
                elif percent * ProgressBar.progressbar_length - math.floor(
                        percent * ProgressBar.progressbar_length) > 1 / 8:
                    progressbar += '▏'
                progressbar = progressbar + ' ' * (ProgressBar.progressbar_length - len(progressbar))
                string = string[0:ProgressBar.progressbar_start] + progressbar + string[ProgressBar.progressbar_start:]

            # ProgressBar.percent_start
            elif operation_id == id(ProgressBar.percent_start):
                if not ProgressBar.counter:
                    percent = value / ProgressBar.max_value * 100
                    if ProgressBar.percent_length != 2:
                        percent = str(float(round(percent * 10 ** (ProgressBar.percent_length - 2))) /
                                      10 ** (ProgressBar.percent_length - 2))
                    else:
                        percent = str(int(round(percent)))
                    string = string[0:ProgressBar.percent_start] + percent + string[ProgressBar.percent_start:]
                else:
                    string = string[0:ProgressBar.percent_start] + str(value) + ProgressBar.counter_separator + \
                             str(ProgressBar.max_value) + string[ProgressBar.percent_start:]

        # вывод
        text_string = ''
        if text is not None:
            text_string = text + ' ' * (len(string) - len(text) + 2) + '\n'

        sys.stdout.write(text_string + string + '\r')
        if value == ProgressBar.max_value:
            sys.stdout.write('\n')



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['koinput']

package_data = \
{'': ['*']}

install_requires = \
['colorama>=0.4.4,<0.5.0']

setup_kwargs = {
    'name': 'koinput',
    'version': '0.3.2',
    'description': 'Maximal simplification of Input / Output for text programs.',
    'long_description': '.. image:: https://img.shields.io/pypi/v/koinput.svg\n    :target: https://pypi.org/project/koinput/\n    :alt: Latest Version\n\n.. image:: https://img.shields.io/pypi/pyversions/koinput.svg\n    :target: https://pypi.org/project/koinput/\n    :alt: Supported Python versions\n\n.. contents:: Table of contents\n    :depth: 3\n\nkoinput\n=======\n\nMaximal simplification of Input / Output for text programs.\n\n`PyPI for releases <https://pypi.org/project/koinput/>`_ |\n`Github for source <https://github.com/k0perX-X/koinput>`_\n\n\nWhat\'s new?\n===========\n\n0.3.2\n    * Minor improvements and bug fixes.\n    * Fixed inaccuracies in README file.\n\n0.3.1\n    * Added multiple input for int_input and float_input.\n\n0.3.0\n    * Added a new ProgressBar function. How to use see below.\n    * Added input_suggestion_style for Menu and Inputs.\n\nInstallation\n============\n\nRequirements `colorama <https://pypi.org/project/colorama/>`_ library.\n\n.. code-block:: bash\n\n    pip install koinput\n\nHow to use\n==========\n\nInputs\n------\n\nThe library has two types of inputs:\n\n* int_input\n* float_input\n\nThey have the same settings and differ only in the type of output.\n\nExplanation of input parameters\n+++++++++++++++++++++++++++++++\n\n.. code-block:: python\n\n    def int_input(input_suggestion: str = \'\', greater: float or int = float(\'-inf\'), less: float or int = float(\'inf\'),\n                  console_style: str = Fore.RESET, error_message: str = \'Invalid number format.\\n\',\n                  error_message_style: str = Fore.RED, multiple_numbers_in_line: bool = False,\n                  input_is_greater_than_less_error: str = "The number is greater than acceptable.\\n",\n                  input_is_less_than_greater_error: str = "The number is less than acceptable.\\n",\n                  input_is_less_error_style: str = None, input_is_greater_error_style: str = None,\n                  strictly_greater: bool = True, strictly_less: bool = True,\n                  input_suggestion_style: str = None) -> int or list:\n\n``input_suggestion=""``\n    Input suggestion that will be displayed when the function is run.\n\n``greater=float(\'-inf\'), less=float(\'inf\')``\n    The range in which the entered number should be included.\n\n``strictly_greater=True, strictly_less=True``\n    Controlling the mathematical strictly of comparisons.\n\n``console_style=colorama.Fore.RESET``\n    Sets the base display style for the terminal. I recommend using the colorama library for easier style customization. You can also use standard sequences (example: "\\x1b[39m").\n\n``error_message=\'Invalid number format.\\n\'``\n    Error message when converting input to number.\n\n``error_message_style=colorama.Fore.RED``\n    Error message style.\n\n``input_is_greater_than_less_error="The number is greater than acceptable.\\n"``\n    The message issued when the number is greater than allowed.\n\n``input_is_less_than_greater_error="The number is less than acceptable.\\n"``\n    The message issued when the number is less than allowed.\n\n``input_is_less_error_style=None, input_is_greater_error_style=None``\n    Out of range error styles.\n\n``input_suggestion_style=None``\n    Input suggestion style.\n\n``multiple_numbers_in_line=False``\n    If True the function will return a list of numbers entered in one line.\n\nUsage example\n+++++++++++++\n\n.. code-block:: python\n\n    def area_triangle(base, height):\n        return 0.5 * base * height\n\n    print(area_triangle(float_input(input_suggestion=\'Enter the base of the triangle: \'),\n                        float_input(input_suggestion=\'Введите высоту треугольника: \')))\n\n.. code-block:: python\n\n    mas = [randint(0, 999) for i in range(int_input(input_suggestion="Enter the size of the array: "))]\n\nMenu\n----\n\nThe menu class is used to quickly create a text menu based on existing functions.\n\nFirst, you need to create an instance of the class:\n\n.. code-block:: python\n\n    from koinput import Menu\n\n    menu = Menu()\n\nThe next step is to add function calls to the menu. This can be done in 2 ways: using a decorator or a function.\n\n.. code-block:: python\n\n    @menu.add_to_menu_dec(\'Name shown in the menu\', *arguments_passed_to_the_function)\n    def z2(a, b, c):\n        def area_circle(radius):\n            return math.pi * radius ** 2\n        print(area_circle(float_input(input_suggestion=\'Введите радиус круга: \')))\n\n    OR\n\n    def z2(a, b, c):\n        def area_circle(radius):\n            return math.pi * radius ** 2\n        print(area_circle(float_input(input_suggestion=\'Введите радиус круга: \')))\n\n    menu.add_to_menu(\'Name shown in the menu\', z2, *arguments_passed_to_the_function)\n\nUse the show_menu command to display the menu.\n\n.. code-block:: python\n\n    def show_menu(self, title: str = None, title_style: str = None, number_of_leading_spaces_title: int = 2,\n                  console_style: str = Fore.RESET, order_of_items: tuple = None, number_of_leading_spaces: int = 4,\n                  separator: str = \' - \', items_style: str = None, input_suggestion: str = \'Select a menu item: \',\n                  enable_menu_item_exit: bool = True, menu_item_exit: str = \'Exit\',\n                  exit_offer: str = \'Press Enter to exit...\', input_suggestion_style: str = None):\n\n``title=None``\n    Menu title.\n\n``title_style=None``\n    Sets the title display style. I recommend using the colorama library for easier style customization. You can also use standard sequences (example: "\\x1b[39m").\n\n``number_of_leading_spaces_title=2``\n    Sets the number of spaces before the menu title.\n\n``console_style=Fore.RESET``\n    Sets the base display style for the terminal. I recommend using the colorama library for easier style customization. You can also use standard sequences (example: "\\x1b[39m").\n\n``number_of_leading_spaces=4``\n    Sets the number of spaces before the menu items.\n\n``separator=\' - \'``\n    Separator between number and menu item name.\n\n``items_style=None``\n    Sets the menu item display style.\n\n``input_suggestion=\'Select a menu item: \'``\n    Input suggestion at the end of the menu.\n\n``input_suggestion_style=None``\n    Input suggestion style.\n\n``enable_menu_item_exit=True``\n    Enabling the menu item exit. If False, then after selecting one of the items the menu will close.\n\n``menu_item_exit=\'Exit\'``\n    The name of the menu exit item.\n\n``exit_offer=\'Press Enter to exit...\'``\n    Exit message.\n\n``order_of_items=None``\n    Custom order of issuing menu items. It is either a tuple of int or a tuple of str. A tuple of int must contain the ordinal numbers of items starting from 0 (the numbers are given in the order in which they are declared). The str tuple must contain the names of the menu items in the order they appear.\n\nChange the function of output from the menu.\n\nThis is necessary when you do not need an exit confirmation or when you exit you need to launch another menu or some function.\n\nExample with disabling the exit confirmation:\n\n.. code-block:: python\n\n    @menu.reassign_menu_exit()\n    def menu_exit(exit_offer):\n        def f():\n            pass\n        return f\n\nExample with displaying another menu:\n\n.. code-block:: python\n\n    @menu.reassign_menu_exit()\n    def menu_exit(exit_offer):\n        def f():\n            menu2.show_menu(title=\'MENU\', title_colour=colorama.Fore.BLUE, enable_menu_item_exit=False)\n        return f\n\nUsage example\n+++++++++++++\n\n.. code-block:: python\n\n    import math\n    from koinput import float_input, Menu\n    import colorama\n\n    menu = Menu()\n\n\n    @menu.add_to_menu_dec(\'Площадь треугольника\')\n    def z1():\n        def area_triangle(base, height):\n            return 0.5 * base * height\n        print(area_triangle(float_input(input_suggestion=\'Введите основание треугольника: \'),\n                            float_input(input_suggestion=\'Введите высоту треугольника: \')))\n\n\n    @menu.add_to_menu_dec(\'Площадь круга\')\n        def z2():\n            def area_circle(radius):\n                return math.pi * radius ** 2\n        print(area_circle(float_input(input_suggestion=\'Введите радиус круга: \')))\n\n\n    @menu.add_to_menu_dec(\'Расстояние от точки до точки\')\n    def z3():\n        def distance(x1, y1, x2, y2):\n            return math.sqrt((x2 - x1) ** 2 + (y2 - y1) ** 2)\n        print(distance(float_input(input_suggestion=\'Введите X первой точки: \'),\n                       float_input(input_suggestion=\'Введите Y первой точки: \'),\n                       float_input(input_suggestion=\'Введите X второй точки: \'),\n                       float_input(input_suggestion=\'Введите Y второй точки: \')))\n\n\n    def z4():\n        def capitalize_word(word):\n            return word[0].upper() + word[1::]\n\n        def capitalize_string(s):\n            ss = s.split()\n            for word in ss:\n                s = s.replace(word, capitalize_word(word))\n            return s\n        print(\'Введите строку для изменения: \')\n        print(capitalize_string(input()))\n\n\n    @menu.reassign_menu_exit()\n    def menu_exit(exit_offer):\n        def f():\n            pass\n        return f\n\n\n    def main():\n        menu.add_to_menu(\'Capitalize\', z4)\n        menu.show_menu(title=\'МЕНЮ\', title_colour=colorama.Fore.BLUE)\n\n\n    if __name__ == \'__main__\':\n        main()\n\nProgressBar\n-----------\n\nThe progress bar is designed to show the progress of long-running tasks.\n\nFirst, we import the ProgressBar class.\n\n.. code-block:: python\n\n    from koinput import ProgressBar\n\nThe class has properties:\n\n``ProgressBar.max_value: int or float = 100``\n    The maximum value from which the percentage is calculated or indicated in the counter mode.\n\n``ProgressBar.counter: bool = False``\n    Enables counter mode. It displays not percentages, but value from max_value.\n\n``ProgressBar.string: str = "[########################################] @@@%"``\n    Indicates the view of the Progress Bar.\n\n``ProgressBar.progressbar_symbol: str = "#"``\n    A symbol indicating the placement of a progress bar.\n\n``ProgressBar.percent_symbol: str = "@"``\n    The symbol indicating the placement of percent (as well as the number of decimal places) or in counter mode only indicates its location.\n\n``ProgressBar.counter_separator: str = \'/\'``\n    A character or string to be displayed between value and max_value in counter mode.\n\nTo display the progress bar, use the show function.\n\n.. code-block:: python\n\n    ProgressBar.show(value: int or float, text: str = None)\n\n``value``\n    The current value of the progress bar.\n\n``text=None``\n    Comment for the current operation.\n\nUsage example\n+++++++++++++\n\n.. code-block:: python\n\n    from koinput import ProgressBar\n    from time import sleep\n\n    ProgressBar.max_value = 123\n    for i in range(124):\n        ProgressBar.show(i)\n        sleep(0.07)\n\n    ProgressBar.max_value = 10\n    ProgressBar.counter = True\n    ProgressBar.string = "|&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&| {*}"\n    ProgressBar.progressbar_symbol = "&"\n    ProgressBar.percent_symbol = "*"\n    ProgressBar.counter_separator = \' element of \'\n    for i in range(11):\n        ProgressBar.show(i, f"Element {i}")\n        sleep(0.7)\n\n',
    'author': 'Николай Перминов',
    'author_email': 'kolya-perminov@ya.ru',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/k0perX-X/koinput',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
